/**
 * Projects with complex multi-platform code should use @rnx-kit/metro-plugin-typescript to properly type check against the platform they are building
 *
 * However, for build steps just using a default config of tsc, this platform neutral definition of the view types will be used.  This is more relaxed
 * and slightly less accurate than the type checking of your bundle using @rnx-kit/metro-plugin-typescript.
 */
import type { TextProps, ViewProps, ImageProps } from 'react-native';
import type { IAdapterMacOSViewProps, IAdapterMacOSTextProps, IAdapterMacOSImageProps } from './adapter.types.macos';
import type { IAdapterWin32ViewProps, IAdapterWin32TextProps, IAdapterWin32ImageProps } from './adapter.types.win32';
import type { IAdapterWindowsViewProps, IAdapterWindowsTextProps, IAdapterWindowsImageProps } from './adapter.types.windows';
export type ITextProps = TextProps & Partial<IAdapterWin32TextProps> & Partial<IAdapterMacOSTextProps> & Partial<IAdapterWindowsTextProps>;
export type IViewProps = ViewProps & Partial<IAdapterWin32ViewProps> & Partial<IAdapterMacOSViewProps> & Partial<IAdapterWindowsViewProps>;
export type IImageProps = ImageProps & Partial<IAdapterWin32ImageProps> & Partial<IAdapterMacOSImageProps> & Partial<IAdapterWindowsImageProps>;
export declare function filterViewProps(propName: string): boolean;
export declare function filterTextProps(propName: string): boolean;
export declare function filterImageProps(propName: string): boolean;
//# sourceMappingURL=adapters.d.ts.map